==> openmsghard-0.0.1.tar.gz: openmsghard-0.0.1/read_conf.c <==
#include "common.h"
#include "read_conf.h"


int loadconfig()
{
  FILE *in = NULL;
  char *left, *right, buf[512];

  in = fopen("/home/msghard/msghard.conf", "r");
  if(in==NULL) 
    return -1;

  /* Set defaults */
  while(fgets(buf, sizeof(buf)-1, in)!=NULL)
  {
    buf[strlen(buf)-1]=0x0;
    /* Skip lines prefixed with '#' */
    if(buf[0]=='#')
      continue;

    /* Skip lines we cannot parse */
    if((left=(char *)split(buf, '=', 0))==NULL)
      continue;

    if((right=(char *)strchr(buf, '='))==NULL)
    {  
      free(left);
      continue;
    }

    *right++;
    if(strcmp(left, "MSN_ID")==0)
      strncpy(conf.msn_id, right, strlen(right));
    else if(strcmp(left, "MSN_PW")==0)
      strncpy(conf.msn_pw, right, strlen(right));
    else if(strcmp(left, "NICK_NAME")==0)
      strncpy(conf.nick_name, right, strlen(right));
    else if(strcmp(left, "MSGHARD_HOME")==0)
      strncpy(conf.msghard_home,right,strlen(right));
    else if(strcmp(left, "IP")==0)
      strncpy(conf.ip, right, strlen(right));
    else if(strcmp(left, "PORT")==0)
      conf.port = atoi(right);
    else if(strcmp(left, "MYSQL_ID")==0)
      strncpy(conf.mysql_id, right, strlen(right));
    else if(strcmp(left, "MYSQL_PW")==0)
      strncpy(conf.mysql_pw, right, strlen(right));
    else if(strcmp(left, "MYSQL_DB")==0)
      strncpy(conf.mysql_db, right, strlen(right)); 
    else if(strcmp(left, "INTRO_MESSAGE")==0)
      strncpy(conf.intro_message, right,strlen(right));
    else if(strcmp(left, "user")==0)
      strncpy(conf.user,right, strlen(right));
    else if(strcmp(left, "group")==0)
      strncpy(conf.user,right, strlen(right));
    else if(strcmp(left, "default_size")==0) {
      conf.default_size = atol(right);
    }
    free(left);
  }

  fclose(in);
  return 0;
}

==> openmsghard-1.0.0.tar.gz: openmsghard-1.0.0/read_conf.c <==
#include "common.h"
#include "read_conf.h"


int loadconfig()
{
  FILE *in = NULL;
  char *left, *right, buf[512];

  in = fopen("/usr/local/src/msghard-0.0.1/msghard.conf", "r");
  if(in==NULL) 
    return -1;

  /* Set defaults */
  while(fgets(buf, sizeof(buf)-1, in)!=NULL)
  {
    buf[strlen(buf)-1]=0x0;
    /* Skip lines prefixed with '#' */
    if(buf[0]=='#')
      continue;

    /* Skip lines we cannot parse */
    if((left=(char *)split(buf, '=', 0))==NULL)
      continue;

    if((right=(char *)strchr(buf, '='))==NULL)
    {  
      free(left);
      continue;
    }

    *right++;
    if(strcmp(left, "MSN_ID")==0)
      strncpy(conf.msn_id, right, strlen(right));
    else if(strcmp(left, "MSN_PW")==0)
      strncpy(conf.msn_pw, right, strlen(right));
    else if(strcmp(left, "NICK_NAME")==0)
      strncpy(conf.nick_name, right, strlen(right));
    else if(strcmp(left, "MSGHARD_HOME")==0)
      strncpy(conf.msghard_home,right,strlen(right));
    else if(strcmp(left, "IP")==0)
      strncpy(conf.ip, right, strlen(right));
    else if(strcmp(left, "PORT")==0)
      conf.port = atoi(right);
    else if(strcmp(left, "MYSQL_ID")==0)
      strncpy(conf.mysql_id, right, strlen(right));
    else if(strcmp(left, "MYSQL_PW")==0)
      strncpy(conf.mysql_pw, right, strlen(right));
    else if(strcmp(left, "MYSQL_DB")==0)
      strncpy(conf.mysql_db, right, strlen(right)); 
    else if(strcmp(left, "INTRO_MESSAGE")==0)
      strncpy(conf.intro_message, right,strlen(right));
    else if(strcmp(left, "user")==0)
      strncpy(conf.user,right, strlen(right));
    else if(strcmp(left, "group")==0)
      strncpy(conf.user,right, strlen(right));
    else if(strcmp(left, "default_size")==0) {
      conf.default_size = atol(right);
    }
    free(left);
  }

  fclose(in);
  return 0;
}
